@@ -2,4 +2,8 @@
 
 __author__ = """Anil Kulkarni"""
 __email__ = 'anil77k@gmail.com'
-__version__ = '0.2.0'
+__version__ = '0.3.0'
+
+
+from .simple_calculator import add
+from .simple_calculator import subtract
\ No newline at end of file
