@@ -8,6 +8,7 @@ import pytest
 from simple_calculator import simple_calculator
 
 
+
 @pytest.fixture
 def response():
     """Sample pytest fixture.
@@ -22,3 +23,11 @@ def test_content(response):
     """Sample pytest test function with the pytest fixture as an argument."""
     # from bs4 import BeautifulSoup
     # assert 'GitHub' in BeautifulSoup(response.content).title.string
+
+def test_add():
+    result = simple_calculator.add(3,4)
+    assert result == 7
+
+def test_subtract():
+    result = simple_calculator.subtract(4,3)
+    assert result == 1
